@@ -1,4 +1,4 @@
-__version__ = '0.5.3'
+__version__ = '0.5.4'
 
 import os
 import re
@@ -33,10 +33,12 @@ DFORM_TYPE_COUNT = 6
 ALLOWED_FORMATS = [np.float32, np.int32, np.int16, np.int8, np.float64, np.int64]
 ALLOWED_EVTYPES = ['all','epocs','snips','streams','scalars']
 
-def get_files(dir, ext):
+def get_files(dir, ext, ignore_mac=False):
     result = []
     for file in os.listdir(dir):
         if file.endswith(ext):
+            if ignore_mac and file.startswith('._'):
+                continue
             result.append(os.path.join(dir, file))
     return result
 
